@@ -19,7 +19,7 @@ export default function PropertyNumber(_ref) {
 
   return React.createElement(
     'div',
-    { style: { marginBottom: "3px" } },
+    { className: 'PropertyNumber', style: { marginBottom: "3px" } },
     React.createElement(
       'div',
       { style: { display: "inline-block", width: "30%" } },
