@@ -137,8 +137,6 @@ function replaceObject(modifiedPath, layer, planData, actions, sceneData, oldSce
   var promises = [];
 
   switch (modifiedPath[3]) {
-    case "layer":
-      break;
     case "vertices":
       break;
     case "holes":
@@ -385,7 +383,7 @@ function addLine(sceneData, planData, layer, lineID, catalog, linesActions) {
       return linesActions.selectLine(layer.id, line.id);
     });
 
-    if (!line.selected) {
+    if (!line.selected && layer.opacity !== 1) {
       applyOpacity(pivot, layer.opacity);
     }
   });
@@ -406,7 +404,7 @@ function addArea(sceneData, planData, layer, areaID, catalog, areaActions) {
 
     applyInteract(pivot, interactFunction);
 
-    if (!area.selected) {
+    if (!area.selected && layer.opacity !== 1) {
       applyOpacity(pivot, layer.opacity);
     }
   });
@@ -429,7 +427,7 @@ function addItem(sceneData, planData, layer, itemID, catalog, itemsActions) {
       itemsActions.selectItem(layer.id, item.id);
     });
 
-    if (!item.selected) {
+    if (!item.selected && layer.opacity !== 1) {
       applyOpacity(pivot, layer.opacity);
     }
 
@@ -454,13 +452,19 @@ function applyOpacity(object, opacity) {
       if (child.material instanceof Three.MultiMaterial) {
         child.material.materials.forEach(function (materialChild) {
           materialChild.transparent = true;
-          if (materialChild.opacity && materialChild.opacity > opacity) {
+          if (materialChild.maxOpacity) {
+            materialChild.opacity = Math.min(materialChild.maxOpacity, opacity);
+          } else if (materialChild.opacity && materialChild.opacity > opacity) {
+            materialChild.maxOpacity = materialChild.opacity;
             materialChild.opacity = opacity;
           }
         });
       } else {
         child.material.transparent = true;
-        if (child.material.opacity && child.material.opacity > opacity) {
+        if (child.material.maxOpacity) {
+          child.material.opacity = Math.min(child.material.maxOpacity, opacity);
+        } else if (child.material.opacity && child.material.opacity > opacity) {
+          child.material.maxOpacity = child.material.opacity;
           child.material.opacity = opacity;
         }
       }
