@@ -6,13 +6,15 @@ export var OPEN_CATALOG = 'OPEN_CATALOG';
 export var SELECT_TOOL_EDIT = 'SELECT_TOOL_EDIT';
 export var UNSELECT_ALL = 'UNSELECT_ALL';
 export var SET_PROPERTIES = 'SET_PROPERTIES';
+export var SET_ITEMS_ATTRIBUTES = 'SET_ITEMS_ATTRIBUTES';
+export var SET_LINES_ATTRIBUTES = 'SET_LINES_ATTRIBUTES';
+export var SET_HOLES_ATTRIBUTES = 'SET_HOLES_ATTRIBUTES';
 export var REMOVE = 'REMOVE';
 export var UNDO = 'UNDO';
 export var ROLLBACK = 'ROLLBACK';
 export var SET_PROJECT_PROPERTIES = 'SET_PROJECT_PROPERTIES';
 export var OPEN_PROJECT_CONFIGURATOR = 'OPEN_PROJECT_CONFIGURATOR';
 export var INIT_CATALOG = 'INIT_CATALOG';
-export var SAVE_SCREENSHOT = 'SAVE_SCREENSHOT';
 
 // ACTIONS viewer2D
 export var SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -99,4 +101,6 @@ export var UNIT_CENTIMETER = 'cm';
 export var UNIT_METER = 'm';
 export var UNIT_INCH = 'in';
 export var UNIT_FOOT = 'ft';
-export var UNIT_MILE = 'mi';
\ No newline at end of file
+export var UNIT_MILE = 'mi';
+
+export var EPSILON = 1e-6;
\ No newline at end of file
