@@ -4,7 +4,7 @@ import FormTextInput from '../../components/style/form-text-input';
 
 export default function PropertyString({value, onUpdate, configs}) {
   return (
-    <div style={{marginBottom: "3px"}}>
+    <div className="PropertyString" style={{marginBottom: "3px"}}>
       <div style={{display: "inline-block", width: "30%"}}>
         <FormLabel>{configs.label}</FormLabel>
       </div>
