@@ -46,7 +46,10 @@ import {
 } from '../../constants';
 
 import ToolbarButton from './toolbar-button';
-const STYLE = {backgroundColor: '#28292D', padding: "10px 10px"};
+const STYLE = {
+  backgroundColor: '#28292D',
+  padding: 10
+};
 
 export default function Toolbar({state, width, height, toolbarButtons, allowProjectFileSupport}, {
   projectActions,
@@ -137,6 +140,8 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
 
 Toolbar.propTypes = {
   state: PropTypes.object.isRequired,
+  width: React.PropTypes.number.isRequired,
+  height: React.PropTypes.number.isRequired,
   allowProjectFileSupport: PropTypes.bool.isRequired
 };
 
