@@ -104,7 +104,7 @@ function updateDrawingHole(state, layerID, x, y) {
       // Now I need min and max possible coordinates for the hole on the line. They depend on the width of the hole
 
       // let width = hole.properties.get('width').get('length');
-      let lineLength = Geometry.distanceFromTwoPoints(x1, y1, x2, y2);
+      let lineLength = Geometry.pointsDistance(x1, y1, x2, y2);
       let alpha = Math.atan2(Math.abs(y2 - y1), Math.abs(x2 - x1));
 
       let cosWithThreshold = (alpha) => {
@@ -230,7 +230,7 @@ function updateDraggingHole(state, x, y) {
   // Now I need min and max possible coordinates for the hole on the line. They depend on the width of the hole
 
   let width = hole.properties.get('width').get('length');
-  let lineLength = Geometry.distanceFromTwoPoints(v0.x, v0.y, v1.x, v1.y);
+  let lineLength = Geometry.pointsDistance(v0.x, v0.y, v1.x, v1.y);
   let alpha = Math.atan2(Math.abs(v1.y - v0.y), Math.abs(v1.x - v0.x));
 
   let cosWithThreshold = (alpha) => {
