@@ -1,12 +1,11 @@
-import {List, Seq, Map, fromJS} from 'immutable';
-import {Layer, Vertex, Line, Hole, Area, ElementsSet, Item} from '../models';
+/** lines features **/
+import {Map, List, fromJS} from 'immutable';
+import {Vertex} from '../models';
 import IDBroker from './id-broker';
 import * as Geometry from './geometry';
 import calculateInnerCyles from './graph-inner-cycles';
+import {EPSILON} from "../constants";
 
-const AREA_ELEMENT_TYPE = 'area';
-
-/** lines features **/
 export function addLine(layer, type, x0, y0, x1, y1, catalog, properties = {}) {
   let line;
 
@@ -88,22 +87,36 @@ export function splitLine(layer, lineID, x, y, catalog) {
 
 export function addLinesFromPoints(layer, type, points, catalog, properties, holes) {
   points = new List(points)
-    .sort(({x:x1, y:y1}, {x:x2, y:y2}) => {
+    .sort(({x: x1, y: y1}, {x: x2, y: y2}) => {
       return x1 === x2 ? y1 - y2 : x1 - x2;
     });
 
   let pointsPair = points.zip(points.skip(1))
-    .filterNot(([{x:x1, y:y1}, {x:x2, y:y2}]) => {
+    .filterNot(([{x: x1, y: y1}, {x: x2, y: y2}]) => {
       return x1 === x2 && y1 === y2;
     });
 
   let lines = (new List()).withMutations(lines => {
     layer = layer.withMutations(layer => {
-      pointsPair.forEach(([{x:x1, y:y1}, {x:x2, y:y2}]) => {
+      pointsPair.forEach(([{x: x1, y: y1}, {x: x2, y: y2}]) => {
         let {line} = addLine(layer, type, x1, y1, x2, y2, catalog, properties);
-        //TODO: Add holes
+        if (holes) {
+          holes.forEach(holeWithOffsetPoint => {
 
+            let {x: xp, y: yp} = holeWithOffsetPoint.offsetPosition;
 
+            if (Geometry.isPointOnLineSegment(x1, y1, x2, y2, xp, yp)) {
+
+              let newOffset = Geometry.pointPositionOnLineSegment(x1, y1, x2, y2, xp, yp);
+
+              if (newOffset >= 0 && newOffset <= 1) {
+
+                addHole(layer, holeWithOffsetPoint.hole.type, line.id, newOffset, catalog,
+                  holeWithOffsetPoint.hole.properties);
+              }
+            }
+          });
+        }
 
         lines.push(line);
       });
@@ -135,6 +148,22 @@ export function addLineAvoidingIntersections(layer, type, x0, y0, x1, y1, catalo
       );
 
       if (intersection.type === "colinear") {
+        if (!oldHoles) {
+          oldHoles = [];
+        }
+
+        layer.lines.get(line.id).holes.forEach(holeID => {
+          let hole = layer.holes.get(holeID);
+          let oldLineLength = Geometry.pointsDistance(v0.x, v0.y, v1.x, v1.y);
+
+          let alpha = Math.atan2(v1.y - v0.y, v1.x - v0.x);
+
+          let xp = oldLineLength * hole.offset * Math.cos(alpha) + v0.x;
+          let yp = oldLineLength * hole.offset * Math.sin(alpha) + v0.y;
+
+          oldHoles.push({hole, offsetPosition: {x: xp, y: yp}});
+        });
+
         removeLine(layer, line.id);
         points.push(v0, v1);
       }
@@ -228,38 +257,86 @@ export function mergeEqualsVertices(layer, vertexID) {
   });
 }
 
-
 export function select(layer, prototype, ID) {
   return layer.withMutations(layer => {
-      layer.setIn([prototype, ID, 'selected'], true);
-      layer.updateIn(['selected', prototype], elements => elements.push(ID));
-    }
-  );
+    layer.setIn([prototype, ID, 'selected'], true);
+    layer.updateIn(['selected', prototype], elements => elements.push(ID));
+  });
 }
 
 export function unselect(layer, prototype, ID) {
   return layer.withMutations(layer => {
-      let ids = layer.getIn(['selected', prototype]);
-      ids = ids.remove(ids.indexOf(ID));
-      let selected = ids.some(key => key === ID);
-      layer.setIn(['selected', prototype], ids);
-      layer.setIn([prototype, ID, 'selected'], selected);
-    }
-  );
+    let ids = layer.getIn(['selected', prototype]);
+    ids = ids.remove(ids.indexOf(ID));
+    let selected = ids.some(key => key === ID);
+    layer.setIn(['selected', prototype], ids);
+    layer.setIn([prototype, ID, 'selected'], selected);
+  });
 }
 
-export function setProperties(layer, prototype, ID, properties) {
+function opSetProperties(layer, prototype, ID, properties) {
   properties = fromJS(properties);
-  return layer.mergeIn([prototype, ID, 'properties'], properties);
+  layer.mergeIn([prototype, ID, 'properties'], properties);
 }
 
+function opSetItemsAttributes(layer, prototype, ID, itemsAttributes) {
+  itemsAttributes = fromJS(itemsAttributes);
+  layer.mergeIn([prototype, ID], itemsAttributes);
+}
+
+function opSetLinesAttributes(layer, prototype, ID, linesAttributes, catalog) {
+
+  let {vertexOne, vertexTwo} = linesAttributes.toJS();
+
+  layer.withMutations(layer => {
+
+    layer
+      .mergeIn(['vertices', vertexOne.id], {x: vertexOne.x, y: vertexOne.y})
+      .mergeIn(['vertices', vertexTwo.id], {x: vertexTwo.x, y: vertexTwo.y})
+      .mergeDeepIn([prototype, ID, 'misc'], new Map({'_unitLength': linesAttributes.get('lineLength').get('_unit')}));
+
+    mergeEqualsVertices(layer, vertexOne.id);
+    //check if second vertex has different coordinates than the first
+    if (vertexOne.x != vertexTwo.x && vertexOne.y != vertexTwo.y) mergeEqualsVertices(layer, vertexTwo.id);
+
+  });
+
+  detectAndUpdateAreas(layer, catalog);
+}
+
+function opSetHolesAttributes(layer, prototype, ID, holesAttributes) {
+
+  let offset = holesAttributes.get('offset');
+
+  let misc = new Map({
+    _unitA: holesAttributes.get('offsetA').get('_unit'),
+    _unitB: holesAttributes.get('offsetB').get('_unit')
+  });
+
+  layer.mergeDeepIn([prototype, ID], new Map({
+    offset,
+    misc
+  }));
+}
+
+
 export function setPropertiesOnSelected(layer, properties) {
   return layer.withMutations(layer => {
     let selected = layer.selected;
-    selected.lines.forEach(lineID => setProperties(layer, 'lines', lineID, properties));
-    selected.holes.forEach(holeID => setProperties(layer, 'holes', holeID, properties));
-    selected.areas.forEach(areaID => setProperties(layer, 'areas', areaID, properties));
-    selected.items.forEach(itemID => setProperties(layer, 'items', itemID, properties));
+    selected.lines.forEach(lineID => opSetProperties(layer, 'lines', lineID, properties));
+    selected.holes.forEach(holeID => opSetProperties(layer, 'holes', holeID, properties));
+    selected.areas.forEach(areaID => opSetProperties(layer, 'areas', areaID, properties));
+    selected.items.forEach(itemID => opSetProperties(layer, 'items', itemID, properties));
+  });
+}
+
+export function setAttributesOnSelected(layer, attributes, catalog) {
+  return layer.withMutations(layer => {
+    let selected = layer.selected;
+    selected.lines.forEach(lineID => opSetLinesAttributes(layer, 'lines', lineID, attributes, catalog));
+    selected.holes.forEach(holeID => opSetHolesAttributes(layer, 'holes', holeID, attributes, catalog));
+    selected.items.forEach(itemID => opSetItemsAttributes(layer, 'items', itemID, attributes, catalog));
+    //selected.areas.forEach(areaID => opSetItemsAttributes(layer, 'areas', areaID, attributes, catalog));
   });
 }
 
@@ -354,7 +431,7 @@ export function detectAndUpdateAreas(layer, catalog) {
           let vertex = layerVertices.get(vertexId);
           return {x: vertex.x, y: vertex.y};
         });
-        addArea(layer, AREA_ELEMENT_TYPE, areaVerticesCoords, catalog)
+        addArea(layer, 'area', areaVerticesCoords, catalog)
       }
     });
   });
